import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="duhdoy",
    version="0.1.0",
    author="Sangarshanan",
    author_email="sangarshanan1998@gmail.com",
    description="Sarcasm Represent-inator",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Sangarshanan/duhdoy",

)
